@@ -2,8 +2,6 @@ import sys
 import pandas as pd
 from xml.etree import ElementTree
 
-from pyrsistent import get_in
-
 
 def merge(files):
     xml_data = None
@@ -35,7 +33,7 @@ def help():
     print("                -h | --help")
 
 def version():
-    print("xmlmerge version: 1.1.1")
+    print("xmlmerge version: 1.1.3")
 
 def get_index(given_list, element):
     try:
@@ -45,8 +43,6 @@ def get_index(given_list, element):
 
 
 def run():
-    if len(sys.argv) <= 2:
-        help()
 
     _help = ['-h', '--help']
     _csv = ['-csv']
@@ -62,6 +58,10 @@ def run():
             version()
             return
 
+    if len(sys.argv) <= 2:
+        help()
+        return
+
     files = []
     csv_name = None
     for i in sys.argv[1:]:
@@ -80,8 +80,8 @@ def run():
         print("you can test with either ls/dir <your-input>")
         return
 
-    print("xml files planning to merge are: ")
-    print(files)
+    # print("xml files planning to merge are: ")
+    # print(files)
     print(merge(files))
 
 
